aboutsummaryrefslogtreecommitdiffstats
path: root/include/sys
diff options
context:
space:
mode:
authorRyan Moeller <[email protected]>2021-04-07 19:23:57 -0400
committerGitHub <[email protected]>2021-04-07 16:23:57 -0700
commite778b0485baaddd55284b138a517e0a028bd15eb (patch)
tree5d86ca456aaa6a3f6a77e176be2595e18969a036 /include/sys
parentc9c6537731d21c00ef5829003db0bb694c6aec56 (diff)
Ratelimit deadman zevents as with delay zevents
Just as delay zevents can flood the zevent pipe when a vdev becomes unresponsive, so do the deadman zevents. Ratelimit deadman zevents according to the same tunable as for delay zevents. Enable deadman tests on FreeBSD and add a test for deadman event ratelimiting. Reviewed-by: Brian Behlendorf <[email protected]> Reviewed-by: Don Brady <[email protected]> Signed-off-by: Ryan Moeller <[email protected]> Closes #11786
Diffstat (limited to 'include/sys')
-rw-r--r--include/sys/vdev_impl.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/sys/vdev_impl.h b/include/sys/vdev_impl.h
index 6c3295353..3cfde40a7 100644
--- a/include/sys/vdev_impl.h
+++ b/include/sys/vdev_impl.h
@@ -458,10 +458,11 @@ struct vdev {
kmutex_t vdev_probe_lock; /* protects vdev_probe_zio */
/*
* We rate limit ZIO delay and ZIO checksum events, since they
* can flood ZED with tons of events when a drive is acting up.
*/
zfs_ratelimit_t vdev_delay_rl;
+ zfs_ratelimit_t vdev_deadman_rl;
zfs_ratelimit_t vdev_checksum_rl;
};
@@ -458,10 +458,11 @@ struct vdev {
kmutex_t vdev_probe_lock; /* protects vdev_probe_zio */
/*
- * We rate limit ZIO delay and ZIO checksum events, since they
+ * We rate limit ZIO delay, deadman, and checksum events, since they
* can flood ZED with tons of events when a drive is acting up.
*/